/* ***********************************************************
 * This file was automatically generated on 2012-12-20.      *
 *                                                           *
 * If you have a bugfix for this file and want to commit it, *
 * please fix the bug in the generator. You can find a link  *
 * to the generator git on tinkerforge.com                   *
 *************************************************************/

#ifndef BRICKLET_GPS_H
#define BRICKLET_GPS_H

#include "ip_connection.h"

/**
 * \defgroup BrickletGPS GPS Bricklet
 */

/**
 * \ingroup BrickletGPS
 *
 * Device for receiving GPS position
 */
typedef Device GPS;

/**
 * \ingroup BrickletGPS
 *
 * This callback is triggered periodically with the period that is set by
 * {@link gps_set_coordinates_callback_period}. The parameters are the same
 * as for {@link gps_get_coordinates}.
 * 
 * {@link GPS_CALLBACK_COORDINATES} is only triggered if the coordinates changed since the
 * last triggering.
 */
#define GPS_CALLBACK_COORDINATES 17

/**
 * \ingroup BrickletGPS
 *
 * This callback is triggered periodically with the period that is set by
 * {@link gps_set_status_callback_period}. The parameters are the same
 * as for {@link gps_get_status}.
 * 
 * {@link GPS_CALLBACK_STATUS} is only triggered if the status changed since the
 * last triggering.
 */
#define GPS_CALLBACK_STATUS 18

/**
 * \ingroup BrickletGPS
 *
 * This callback is triggered periodically with the period that is set by
 * {@link gps_set_altitude_callback_period}. The parameters are the same
 * as for {@link gps_get_altitude}.
 * 
 * {@link GPS_CALLBACK_ALTITUDE} is only triggered if the altitude changed since the
 * last triggering.
 */
#define GPS_CALLBACK_ALTITUDE 19

/**
 * \ingroup BrickletGPS
 *
 * This callback is triggered periodically with the period that is set by
 * {@link gps_set_motion_callback_period}. The parameters are the same
 * as for {@link gps_get_motion}.
 * 
 * {@link GPS_CALLBACK_MOTION} is only triggered if the motion changed since the
 * last triggering.
 */
#define GPS_CALLBACK_MOTION 20

/**
 * \ingroup BrickletGPS
 *
 * This callback is triggered periodically with the period that is set by
 * {@link gps_set_date_time_callback_period}. The parameters are the same
 * as for {@link gps_get_date_time}.
 * 
 * {@link GPS_CALLBACK_DATE_TIME} is only triggered if the date or time changed since the
 * last triggering.
 */
#define GPS_CALLBACK_DATE_TIME 21

/**
 * \ingroup BrickletGPS
 *
 * Creates an object with the unique device ID \c uid. This object can then be
 * added to the IP connection.
 */
void gps_create(GPS *gps, const char *uid);

/**
 * \ingroup BrickletGPS
 *
 * Returns the GPS coordinates. Latitude and longitude are given in the
 * DD.dddddd° format. The parameter ns and ew are the cardinal directions for
 * latitude and logitude. Possible values for ns and ew are 'N', 'S', 'E'
 * and 'W' (north, south, east and west).
 * 
 * PDOP, HDOP and VDOP are the dilution of precision (DOP) values. They specify
 * the additional multiplicative effect of GPS satellite geometry on GPS 
 * precision. See 
 * `here <http://en.wikipedia.org/wiki/Dilution_of_precision_(GPS)>`__
 * for more information. The values are give in hundreths.
 * 
 * EPE is the "Estimated Position Error". The EPE is given in cm. This is not the
 * absolute maximum error, it is the error with a specific confidence. See
 * `here <http://www.nps.gov/gis/gps/WhatisEPE.html>`__ for more information.
 */
int gps_get_coordinates(GPS *gps, uint32_t *ret_latitude, char *ret_ns, uint32_t *ret_longitude, char *ret_ew, uint16_t *ret_pdop, uint16_t *ret_hdop, uint16_t *ret_vdop, uint16_t *ret_epe);

/**
 * \ingroup BrickletGPS
 *
 * Returns the current fix status, the number of satellites that are in view and
 * the number of satellites that are currently used.
 * 
 * Possible fix status values can be:
 * 
 * \verbatim
 *  "Value", "Description"
 * 
 *  "1", "No Fix"
 *  "2", "2D Fix"
 *  "3", "3D Fix"
 * \endverbatim
 */
int gps_get_status(GPS *gps, uint8_t *ret_fix, uint8_t *ret_satellites_view, uint8_t *ret_satellites_used);

/**
 * \ingroup BrickletGPS
 *
 * Returns the current altitude and corresponding geoidal separation.
 * 
 * Both values are given in cm.
 */
int gps_get_altitude(GPS *gps, uint32_t *ret_altitude, uint32_t *ret_geoidal_separation);

/**
 * \ingroup BrickletGPS
 *
 * Returns the current course and speed. Course is given in hundreths degree
 * and speed is given in hundreths km/h.
 * 
 * Please note that this only returns useful values if an actual movement
 * is present.
 */
int gps_get_motion(GPS *gps, uint32_t *ret_course, uint32_t *ret_speed);

/**
 * \ingroup BrickletGPS
 *
 * Returns the current date and time. The date is
 * given in the format ddmmyy and the time is given
 * in the format hhmmss.sss
 */
int gps_get_date_time(GPS *gps, uint32_t *ret_date, uint32_t *ret_time);

/**
 * \ingroup BrickletGPS
 *
 * Restarts the GPS Bricklet, the following restart types are available:
 * 
 * \verbatim
 *  "Value", "Description"
 * 
 *  "0", "Hot start (use all available data in the NV store)"
 *  "1", "Warm start (don't use ephemeris at restart)"
 *  "2", "Cold start (don't use time, position, almanacs and ephemeris at restart)"
 *  "3", "Factory reset (clear all system/user configurations at restart)"
 * \endverbatim
 */
int gps_restart(GPS *gps, uint8_t restart_type);

/**
 * \ingroup BrickletGPS
 *
 * Sets the period in ms with which the {@link GPS_CALLBACK_COORDINATES} callback is triggered
 * periodically. A value of 0 turns the callback off.
 * 
 * {@link GPS_CALLBACK_COORDINATES} is only triggered if the coordinates changed since the
 * last triggering.
 * 
 * The default value is 0.
 */
int gps_set_coordinates_callback_period(GPS *gps, uint32_t period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the period as set by {@link gps_set_coordinates_callback_period}.
 */
int gps_get_coordinates_callback_period(GPS *gps, uint32_t *ret_period);

/**
 * \ingroup BrickletGPS
 *
 * Sets the period in ms with which the {@link GPS_CALLBACK_STATUS} callback is triggered
 * periodically. A value of 0 turns the callback off.
 * 
 * {@link GPS_CALLBACK_STATUS} is only triggered if the status changed since the
 * last triggering.
 * 
 * The default value is 0.
 */
int gps_set_status_callback_period(GPS *gps, uint32_t period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the period as set by {@link gps_set_status_callback_period}.
 */
int gps_get_status_callback_period(GPS *gps, uint32_t *ret_period);

/**
 * \ingroup BrickletGPS
 *
 * Sets the period in ms with which the {@link GPS_CALLBACK_ALTITUDE} callback is triggered
 * periodically. A value of 0 turns the callback off.
 * 
 * {@link GPS_CALLBACK_ALTITUDE} is only triggered if the altitude changed since the
 * last triggering.
 * 
 * The default value is 0.
 */
int gps_set_altitude_callback_period(GPS *gps, uint32_t period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the period as set by {@link gps_set_altitude_callback_period}.
 */
int gps_get_altitude_callback_period(GPS *gps, uint32_t *ret_period);

/**
 * \ingroup BrickletGPS
 *
 * Sets the period in ms with which the {@link GPS_CALLBACK_DATE_TIME} callback is triggered
 * periodically. A value of 0 turns the callback off.
 * 
 * {@link GPS_CALLBACK_DATE_TIME} is only triggered if the date or time changed since the
 * last triggering.
 * 
 * The default value is 0.
 */
int gps_set_date_time_callback_period(GPS *gps, uint32_t period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the period as set by {@link gps_set_date_time_callback_period}.
 */
int gps_get_date_time_callback_period(GPS *gps, uint32_t *ret_period);

/**
 * \ingroup BrickletGPS
 *
 * Sets the period in ms with which the {@link GPS_CALLBACK_MOTION} callback is triggered
 * periodically. A value of 0 turns the callback off.
 * 
 * {@link GPS_CALLBACK_MOTION} is only triggered if the motion changed since the
 * last triggering.
 * 
 * The default value is 0.
 */
int gps_set_motion_callback_period(GPS *gps, uint32_t period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the period as set by {@link gps_set_motion_callback_period}.
 */
int gps_get_motion_callback_period(GPS *gps, uint32_t *ret_period);

/**
 * \ingroup BrickletGPS
 *
 * Returns the name (including the hardware version), the firmware version
 * and the binding version of the device. The firmware and binding versions are
 * given in arrays of size 3 with the syntax [major, minor, revision].
 */
int gps_get_version(GPS *gps, char ret_name[40], uint8_t ret_firmware_version[3], uint8_t ret_binding_version[3]);

/**
 * \ingroup BrickletGPS
 *
 * Registers a callback with ID \c id to the function \c callback.
 */
void gps_register_callback(GPS *gps, uint8_t id, void *callback);

#endif
